@@ -1,6 +1,6 @@
 /*************************************************
 * Base64 Encoder/Decoder Source File             *
-* (C) 1999-2006 The Botan Project                *
+* (C) 1999-2007 The Botan Project                *
 *************************************************/
 
 #include <botan/base64.h>
@@ -12,8 +12,8 @@ namespace Botan {
 /*************************************************
 * Base64_Encoder Constructor                     *
 *************************************************/
-Base64_Encoder::Base64_Encoder(bool breaks, u32bit length) :
-   line_length(breaks ? length : 0)
+Base64_Encoder::Base64_Encoder(bool breaks, u32bit length, bool t_n) :
+   line_length(breaks ? length : 0), trailing_newline(t_n)
    {
    in.create(48);
    out.create(4);
@@ -118,7 +118,7 @@ void Base64_Encoder::end_msg()
       do_output(out, 4);
       }
 
-   if(counter && line_length)
+   if(trailing_newline || (counter && line_length))
       send('\n');
 
    counter = position = 0;
@@ -169,13 +169,15 @@ void Base64_Decoder::decode_and_send(const byte block[], u32bit length)
 *************************************************/
 void Base64_Decoder::handle_bad_char(byte c)
    {
-   if(checking == NONE)
+   if(c == '=' || checking == NONE)
       return;
 
    if((checking == IGNORE_WS) && Charset::is_space(c))
       return;
 
-   throw Decoding_Error("Base64_Decoder: Invalid base64 character: " + c);
+   throw Decoding_Error(
+      std::string("Base64_Decoder: Invalid base64 character '") + (char)c + "'"
+      );
    }
 
 /*************************************************
